
RELEASE_VERSION='0.0.426186153'
BUILD_DATE='Thu Dec  9 14:56:29 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-t4krtqay-project-28359933-concurrent-0mb77q 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1867825688'
GIT_COMMIT_SHA='409e4371f75ba72d2cbcdf8af86fc6c20bd80f97'
GIT_BRANCH='main'
